## Ticket

Provide a link to the [project](https://github.com/orgs/omnibenchmark/projects/1) ticket.

## Description

Provide a small description of Pull Request.

## Checklist:
- [ ] My code follows the code style of this project.
- [ ] My CLI method respects the signature defined in the task.
- [ ] I have documented the CLI method accordingly.
- [ ] I have added tests to cover my changes.
- [ ] I have added a CHANGELOG entry.

## Remarks for the reviewer:

Leave here some remarks for the reviewer.